# giwaxs_gui
### A graphical tool for GIWAXS data analysis.

giwaxs_gui contains all the basic functionality for 
the analysis of 2D diffraction images with circular symmetry. 
In particular, it focuses on grazing-incidence wide-angle scattering
data and its specific needs.

## Install
### Pip install 
To install current release via pip, you should have python installed 
on your computer. The minimum required version is 3.6.0. Install package via pip:

```sh
pip install giwaxs_gui
```

After installation you can launch the program:
```sh
python
>>>from giwaxs_gui import run
>>>run()
```
